package com.bernhardriedl.projects.henonattractor.gui;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;

import com.bernhardriedl.projects.henonattractor.images.ImagesContainer;
import com.bernhardriedl.projects.henonattractor.logic.Iterator;
import com.bernhardriedl.projects.henonattractor.logic.IteratorTask;
import com.bernhardriedl.projects.tools.gui.EnhancedButton;

/**
 * IteratorContainer
 * @author Bernhard Riedl
 */

public class IteratorContainer extends JFrame implements ActionListener {

	private static final long serialVersionUID = 4557627523029746637L;

	/*
	 * GUI
	 */
	
	private EnhancedButton stop_animation=new EnhancedButton();
	
	/*
	 * Logic
	 */
	
	private Iterator it;
	private IteratorTask it_task;
	
	private boolean animation;

	/**
	 * construktor
	 * @param a value for a
	 * @param b value for b
	 * @param animation animation or single calculation
	 * @param parent parent container
	 * */

	public IteratorContainer(double a, double b, boolean animation, JFrame parent) {

		this.animation=animation;

		this.setIconImage(ImagesContainer.icon.getImage());

		/*
		 * do we handle an animation request?
		 */
		
		if (!animation)
			this.it=new Iterator(a, b, animation);
		else
			this.it_task=new IteratorTask(a, b);

		this.stop_animation.setText("Stop Animation");
		this.stop_animation.setIcon(ImagesContainer.iconAnimation16);
		this.stop_animation.addActionListener(this);
		
		this.getContentPane().setLayout(new BorderLayout());

		if (!animation)
			this.getContentPane().add("Center",it);
		else
			this.getContentPane().add("Center",it_task.getIterate());

    this.getContentPane().add("South", stop_animation);

    this.setSize(600,450);
    this.setLocation(250,250);

    this.setVisible(true);

    if (this.animation)
    	this.it_task.start();
    else {
      this.stop_animation.setText("close");
    }

  }

	public void actionPerformed(ActionEvent e) {
		if (e.getSource().equals(this.stop_animation))
			this.stopAnimation();
	}

	/**
   * Overridden so we can exit when window is closed
   * <p>
   * @param e WindowEvent
   */

  protected void processWindowEvent(WindowEvent e)
  {
    if (e.getID() == WindowEvent.WINDOW_CLOSING)
    {
      this.stopAnimation();
    }
  }

  /**
   * stopAnimation
   */

  private void stopAnimation() {
    if (this.animation) {
      this.it_task.setStop(true);
    }
    this.dispose();
  }

}
