package com.bernhardriedl.projects.tools.gui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.Frame;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.util.Vector;

import javax.swing.AbstractAction;
import javax.swing.BorderFactory;
import javax.swing.InputMap;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JRootPane;
import javax.swing.JTextArea;
import javax.swing.KeyStroke;

public class AboutDialog
    extends JDialog {
	
	private static final long serialVersionUID = 5813671295134441562L;

	/**
	 * GUI-Components
	 */
	
	private JPanel header = new JPanel();
	private JPanel content = new JPanel();
	private JPanel links = new JPanel();
	
	private URLTextField programm=null;
	private URLTextField author=null;
	private JTextArea info = new JTextArea();
	
	/**
	 * Constructor
	 * @param owner owner-frame
	 * @param title program-title
	 * @param version program-version
	 * @param years copyright-years
	 * @param author author(s)
	 * @param text descriptive text
	 * @param width width
	 * @param height height
	 */
	
	public AboutDialog(Frame owner, String title, String version, String years, String author, Vector <String> text, Vector <String> urls, int width, int height) {
		super(owner, true);
		
		this.setTitle("About");
		
		this.setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);

		this.makeComponents(title, version, years, author, text, urls);
		
		this.content.setBackground(Color.white);
		this.content.add("Center", info);

		this.setContentPane(content);

		this.setResizable(false);
		//this.setUndecorated(true);
		this.setSize(width, height);
		
		com.bernhardriedl.projects.tools.gui.Utils.centerWindow(this);
		
		this.setVisible(true);
	}
	
	protected JRootPane createRootPane() {
		JRootPane rootPane = new JRootPane();
		KeyStroke stroke = KeyStroke.getKeyStroke("ESCAPE");
		
		AbstractAction actionListener = new AbstractAction() {
			private static final long serialVersionUID = -167753825494413553L;

			public void actionPerformed(ActionEvent actionEvent) {
				dispose();
			}
		};
		
		InputMap inputMap = rootPane.getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW);
		inputMap.put(stroke, "ESCAPE");
		rootPane.getActionMap().put("ESCAPE", actionListener);

		return rootPane;
	}

	private void makeComponents(String title, String version, String years, String author, Vector <String> text, Vector <String> urls) {
		this.content.setLayout(new BorderLayout());
		this.content.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
		
		/**
		 * header
		 */
		
		this.header.setLayout(new GridLayout(2,0));
		this.header.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
		this.header.setBackground(Color.WHITE);
		
		this.programm=new URLTextField(title+" v" + version + ", "+years+"\n", "https://www.bernhard-riedl.com/projects/");
		this.programm.setFont(new Font("Courier", 1, 13));
		
		this.author=new URLTextField("(c) "+author+"\n\n", "https://www.bernhard-riedl.com/");
		
		/**
		 * info-text
		 */
		
		this.header.add(this.programm);
		this.header.add(this.author);
		
		this.content.add(this.header, BorderLayout.NORTH);
    
		for (String entry : text)
			this.info.append(entry+"\n");

		this.info.setEditable(false);
		this.info.setEnabled(false);
		this.info.setForeground(Color.BLACK);
		this.info.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
		this.info.setBackground(Color.WHITE);
		this.info.setDisabledTextColor(Color.BLACK);
		this.info.setFont(new Font("Courier", 1, 11));

		this.content.add(info, BorderLayout.CENTER);

		/**
		 * urls
		 */
		
		if (urls.size()>0) {
			this.links.setLayout(new GridLayout(urls.size(), 0));
			this.links.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
			this.links.setBackground(Color.WHITE);

			for(String url : urls) {
				URLTextField textfield=new URLTextField(url, url);        		
				this.links.add(textfield);
			}
      		
			this.content.add(this.links, BorderLayout.SOUTH);
		}

		this.content.setBackground(Color.white);
	}
	  
	  public void actionPerformed(ActionEvent e) {
		  this.dispose();
	  }
	
}